@@ -6,5 +6,5 @@
 # All rights reserved.
 # -------------------------------
 
-from .bitpacksender import BitPackSender
-from .bitpackreceiver import BitPackReceiver
\ No newline at end of file
+from .safesender import SafeSender
+from .safereceiver import SafeReceiver
\ No newline at end of file
